==> haskell-hunit-1.6.2.0-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HUnit
version:              1.6.2.0
visibility:           public
id:                   HUnit-1.6.2.0-4qFm36ACLL54EZhrCfb7eW
key:                  HUnit-1.6.2.0-4qFm36ACLL54EZhrCfb7eW
license:              BSD-3-Clause
maintainer:           Simon Hengel <sol@typeful.net>
author:               Dean Herington
stability:            stable
homepage:             https://github.com/hspec/HUnit#readme
synopsis:             A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.

category:             Testing
abi:                  ce784f604726bad4b606fbcce8f5155a
exposed:              True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text

hidden-modules:       Paths_HUnit
import-dirs:          /usr/lib/ghc-9.0.2/site-local/HUnit-1.6.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/HUnit-1.6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/HUnit-1.6.2.0
hs-libraries:         HSHUnit-1.6.2.0-4qFm36ACLL54EZhrCfb7eW
depends:
    base-4.15.1.0 call-stack-0.4.0-Fkgzm6qlhhEJQjCuecqIFQ
    deepseq-1.4.5.0

haddock-interfaces:   /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html:         /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hunit-1.6.2.0-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HUnit
version:              1.6.2.0
visibility:           public
id:                   HUnit-1.6.2.0-KAwdAgbRzrx72Ur0Y1YkJC
key:                  HUnit-1.6.2.0-KAwdAgbRzrx72Ur0Y1YkJC
license:              BSD-3-Clause
maintainer:           Simon Hengel <sol@typeful.net>
author:               Dean Herington
stability:            stable
homepage:             https://github.com/hspec/HUnit#readme
synopsis:             A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.

category:             Testing
abi:                  94a6574ea12cab41c990adebbb4d2571
exposed:              True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text

hidden-modules:       Paths_HUnit
import-dirs:          /usr/lib/ghc-9.0.2/site-local/HUnit-1.6.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/HUnit-1.6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/HUnit-1.6.2.0
hs-libraries:         HSHUnit-1.6.2.0-KAwdAgbRzrx72Ur0Y1YkJC
depends:
    base-4.15.1.0 call-stack-0.4.0-6JET1pROhIkC7Lt9wogpdC
    deepseq-1.4.5.0

haddock-interfaces:   /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html:         /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
